@@ -9,7 +9,7 @@ tcplMthdClear <- function(lvl, id, mthd_id = NULL, type) {
   
   if (length(lvl) > 1) stop("'lvl' must be an integer of length 1.")
   if (!type %in% c("mc", "sc")) stop("Invalid 'type' value.")
-  if (type == "mc" & !lvl %in% c(2, 3, 5, 6)) stop("Invalid 'lvl' value.")
+  if (type == "mc" & !lvl %in% c(2, 3,4, 5, 6)) stop("Invalid 'lvl' value.")
   if (type == "sc" & !lvl %in% 1:2) stop("Invalid 'lvl' value.")
   
   fld <- if (type == "mc" & lvl == 2) "acid" else "aeid"
